<?php

namespace Drupal\config_partial_override;

use Drupal\Component\Utility\NestedArray;
use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Config\ConfigFactoryOverrideInterface;
use Drupal\Core\Config\StorageInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Symfony\Component\Yaml\Yaml;

class ConfigPartialOverrideFactory implements ConfigFactoryOverrideInterface {

  /**
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * @var null
   */
  protected $override_files = NULL;

  /**
   * ConfigPartialOverrideFactory constructor.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   */
  public function __construct(ModuleHandlerInterface $module_handler) {
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritdoc}
   */
  public function loadOverrides($names) {
    $overrides = [];
    foreach ($this->moduleHandler->getModuleList() as $module) {
      $module_path = $module->getPath();
      $override_dir = $module_path . DIRECTORY_SEPARATOR . 'config' . DIRECTORY_SEPARATOR . 'override';
      if (file_exists($override_dir) && $files = file_scan_directory($override_dir, '/^.*\.yml$/i')) {
        foreach ($files as $file) {
          $override_file = file_get_contents($override_dir . DIRECTORY_SEPARATOR . $file->name . '.yml');
          $this->override_files[$module->getName()][$file->name] = Yaml::parse($override_file);
        }
      }
    }
    // Loop through each module that provides overrides.
    if (!empty($this->override_files)) {
      foreach ($this->override_files as $module_name => $file) {
        // Set each override from the provided configuration.
        foreach ($file as $config_name => $config_override) {
          $overrides[$config_name] = $config_override;
        }
      }
    }
    return $overrides;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheSuffix() {
    return 'config_partial_override';
  }

  /**
   * {@inheritdoc}
   */
  public function createConfigObject($name, $collection = StorageInterface::DEFAULT_COLLECTION) {
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata($name) {
    return new CacheableMetadata();
  }


}
